@@ -217,7 +217,7 @@ std::vector<char> fill_buf(
           // TODO: use something like https://github.com/jeaiii/itoa for
           // faster integer writing
           char temp_buf[12];
-          auto len = sprintf(temp_buf, "%i", value);
+          auto len = snprintf(temp_buf, sizeof(temp_buf), "%i", value);
           std::copy(temp_buf, temp_buf + len, std::back_inserter(buf));
         }
         break;
@@ -319,7 +319,7 @@ std::vector<char> get_header(
       out.push_back(delim);
     }
   }
-  if(out.size() != 0) {
+  if(!out.empty()) {
     if (delim != '\0') {
       out.pop_back();
     }
@@ -381,7 +381,7 @@ void vroom_write_out(
       auto end = begin + num_lines;
       futures[idx][t++] = std::async(
           fill_buf,
-          input,
+          std::cref(input),
           delim,
           eol,
           na_str,
@@ -526,7 +526,7 @@ void vroom_write_out(
       auto end = begin + num_lines;
       futures[idx][t++] = std::async(
           fill_buf,
-          input,
+          std::cref(input),
           delim,
           eol,
           na_str,
